/*
 * CDDL HEADER START
 *
 * The contents of this file are subject to the terms of the
 * Common Development and Distribution License, Version 1.0 only
 * (the "License").  You may not use this file except in compliance
 * with the License.
 *
 * You can obtain a copy of the license at /OPENSPML_V2_TOOLKIT.LICENSE
 * or http://www.openspml.org/v2/licensing.
 * See the License for the specific language governing permissions
 * and limitations under the License.
 *
 * When distributing Covered Code, include this CDDL HEADER in each
 * file and include the License file at /OPENSPML_V2_TOOLKIT.LICENSE.
 * If applicable, add the following below this CDDL HEADER, with the
 * fields enclosed by brackets "[]" replaced with your own identifying
 * information: Portions Copyright [yyyy] [name of copyright owner]
 *
 * CDDL HEADER END
 */
/*
 * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
 * Use is subject to license terms.
 */
package org.openspml.v2.profiles.dsml;

import org.openspml.v2.util.xml.XmlBuffer;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;

/**
 * There's only one SubstringFilter typed item, the Substring element, so
 * we're using a single class.
 * <p/>
 * <pre>
 * &lt;xsd:complexType name="SubstringFilter"&gt;
 *     &lt;xsd:sequence&gt;
 *         &lt;xsd:element name="initial" type="DsmlValue" minOccurs="0"/&gt;
 *         &lt;xsd:element name="any" type="DsmlValue" minOccurs="0" maxOccurs="unbounded"/&gt;
 *         &lt;xsd:element name="final" type="DsmlValue" minOccurs="0"/&gt;
 *     &lt;/xsd:sequence&gt;
 *     &lt;xsd:attribute name="name" type="AttributeDescriptionValue" use="required"/&gt;
 * &lt;/xsd:complexType&gt;
 * </pre>
 */
public class Substrings extends NamedFilterItem {

    private static final String code_id = "$Id: Substrings.java,v 1.6 2006/06/10 02:13:32 kas Exp $";

    // xsd:element name="initial" type="DsmlValue" minOccurs="0"
    private Value mInitial = null;

    // xsd:element name="any" type="DsmlValue" minOccurs="0" maxOccurs="unbounded"
    private List mAny = new ArrayList();

    // xsd:element name="final" type="DsmlValue" minOccurs="0"
    private Value mFinal = null;

    public Substrings() {
    }

    protected void toXML(XmlBuffer buffer) throws DSMLProfileException {
        super.toXML("substrings", buffer);
    }

    protected void addSubclassElements(XmlBuffer buffer) throws DSMLProfileException {
        if (mInitial != null) {
            mInitial.toXML("initial", buffer);
        }

        for (int k = 0; k < mAny.size(); k++) {
            Value value = (Value) mAny.get(k);
            value.toXML("any", buffer);
        }

        if (mFinal != null) {
            mFinal.toXML("final", buffer);
        }
    }

    public void parseXml(DSMLUnmarshaller um, Object e) throws DSMLProfileException {
        um.visitSubstrings(this, e);
    }

    public Value getInitial() {
        return mInitial;
    }

    public void setInitial(Value initial) {
        mInitial = initial;
    }

    public Value[] getAny() {
        return (Value[]) mAny.toArray(new Value[mAny.size()]);
    }

    public void setAny(Value[] any) {
        if (any != null) {
            mAny.clear();
            mAny.addAll(Arrays.asList(any));
        }
    }

    public void addAny(Value any) {
        if (any != null) mAny.add(any);
    }

    public boolean removeAny(Value any) {
        if (any != null) return mAny.remove(any);
        return false;
    }

    public void clearAny() {
        mAny.clear();
    }

    public Value getFinal() {
        return mFinal;
    }

    public void setFinal(Value aFinal) {
        mFinal = aFinal;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (!(o instanceof Substrings)) return false;
        if (!super.equals(o)) return false;

        final Substrings substrings = (Substrings) o;

        if (mAny != null ? !mAny.equals(substrings.mAny) : substrings.mAny != null) return false;
        if (mFinal != null ? !mFinal.equals(substrings.mFinal) : substrings.mFinal != null) return false;
        if (mInitial != null ? !mInitial.equals(substrings.mInitial) : substrings.mInitial != null) return false;

        return true;
    }

    public int hashCode() {
        int result = super.hashCode();
        result = 29 * result + (mInitial != null ? mInitial.hashCode() : 0);
        result = 29 * result + (mAny != null ? mAny.hashCode() : 0);
        result = 29 * result + (mFinal != null ? mFinal.hashCode() : 0);
        return result;
    }
}
