/*
 * CDDL HEADER START
 *
 * The contents of this file are subject to the terms of the
 * Common Development and Distribution License, Version 1.0 only
 * (the "License").  You may not use this file except in compliance
 * with the License.
 *
 * You can obtain a copy of the license at /OPENSPML_V2_TOOLKIT.LICENSE
 * or http://www.openspml.org/v2/licensing.
 * See the License for the specific language governing permissions
 * and limitations under the License.
 *
 * When distributing Covered Code, include this CDDL HEADER in each
 * file and include the License file at /OPENSPML_V2_TOOLKIT.LICENSE.
 * If applicable, add the following below this CDDL HEADER, with the
 * fields enclosed by brackets "[]" replaced with your own identifying
 * information: Portions Copyright [yyyy] [name of copyright owner]
 *
 * CDDL HEADER END
 */
/*
 * Copyright 2006 Tripod Technology Group, Inc.
 * All Rights Reserved.
 * Use is subject to license terms.
 */
package org.openspml.v2.profiles.dsml;

import junit.framework.TestCase;
import junit.textui.TestRunner;
import org.openspml.v2.msg.Marshallable;
import org.openspml.v2.msg.XMLMarshaller;
import org.openspml.v2.msg.XMLUnmarshaller;
import org.openspml.v2.msg.OpenContentElement;
import org.openspml.v2.msg.spml.ListTargetsResponse;
import org.openspml.v2.profiles.DSMLProfileRegistrar;
import org.openspml.v2.util.xml.ObjectFactory;
import org.openspml.v2.util.xml.ReflectiveDOMXMLUnmarshaller;
import org.openspml.v2.util.xml.ReflectiveXMLMarshaller;
import org.openspml.util.XmlParser;
import org.w3c.dom.Document;
import org.w3c.dom.Element;

public class MiscDsmlTest extends TestCase {

    static final String LIST_TARGETS_RESPONSE = "<listTargetsResponse status=\"success\" xmlns=\"urn:oasis:names:tc:SPML:2:0\">\n"
            + "    <target targetID=\"http://www.summittrust.com\">\n"
            + "        <schema>\n"
            + "            <schema xmlns:xsd=\"http://www.w3.org/2001/XMLSchema\" xmlns:xsi=\"http://www.w3.org/2001/XMLSchema-instance\" xmlns=\"urn:oasis:names:tc:SPML:2:0:DSML\">\n"
            + "                <objectClassDefinition name=\"user\">\n"
            + "                    <memberAttributes>\n"
            + "                        <attributeDefinitionReference name=\"uid\"/>\n"
            + "                        <attributeDefinitionReference name=\"mail\"/>\n"
            + "                        <attributeDefinitionReference name=\"description\"/>\n"
            + "                    </memberAttributes>\n"
            + "                </objectClassDefinition>\n"
            + "                <attributeDefinition name=\"uid\"/>\n"
            + "                <attributeDefinition name=\"mail\"/>\n"
            + "                <attributeDefinition name=\"description\"/>\n"
            + "            </schema>\n"
            + "        </schema>\n"
            + "        <capabilities>\n"
            + "            <capability namespaceURI=\"urn:oasis:names:tc:SPML:2:0:password\">\n"
            + "                <appliesTo entityName=\"user\"/>\n"
            + "            </capability>\n"
            + "            <capability namespaceURI=\"urn:oasis:names:tc:SPML:2:0:suspend\">\n"
            + "                <appliesTo entityName=\"user\"/>\n"
            + "            </capability>\n"
            + "            <capability namespaceURI=\"urn:oasis:names:tc:SPML:2:0:search\"/>\n"
            + "        </capabilities>\n"
            + "    </target>\n"
            + "</listTargetsResponse>\n";

    public static void main(String[] args) {
        TestRunner.run(MiscDsmlTest.class);
    }

    XMLMarshaller mMarshaller = null;
    XMLUnmarshaller mUnmarshaller = null;

    public MiscDsmlTest(String name) {
        super(name);
    }

    protected void setUp() throws Exception {
        mMarshaller = new ReflectiveXMLMarshaller();
        mUnmarshaller = new ReflectiveDOMXMLUnmarshaller();
        ObjectFactory.getInstance().register(new DSMLProfileRegistrar());
    }

    public void testListTargetsResponse() {
        try {
            String xml = LIST_TARGETS_RESPONSE;

            System.out.println("----------------------------------------------------------------------");

            // unmarshal:
            System.out.println("\nUnmarshalling request xml:\n" + xml);
            Marshallable resp = mUnmarshaller.unmarshall(xml);
            System.out.println("Unmarshalling complete");
            System.out.println("-- Resulting class: " + resp.getClass().getName());

            ListTargetsResponse ltr = (ListTargetsResponse) resp;
            xml = ltr.toXML(mMarshaller);

            System.out.println("Marshalled xml = \n\n" + xml);
        }
        catch (Exception e) {
            fail(e.getMessage());
        }
    }

    public void testAttrAlone() {
        try {
            System.out.println("----------------------------------------------------------------------");
            DSMLAttr attr = new DSMLAttr("testattr", "testvalue");

            String xml = attr.toXML();
            System.out.println("xml = \n" + xml);

            Value[] values = new Value[] {
                new DSMLValue("one"),
                new DSMLValue("two"),
                new DSMLValue("three"),
            };
            attr.setValues(values);

            xml = attr.toXML();
            System.out.println("xml with 3 values = \n" + xml);

            xml = "<dsml:attr xmlns:dsml='urn:oasis:names:tc:DSML:2:0:core' name='attr'>\n"
                    + "    <dsml:value>value</dsml:value>\n"
                    + "    <dsml:value>value2</dsml:value>\n"
                    + "</dsml:attr>";

            // testing this a tad tricky...
            Document doc = XmlParser.parse(xml, false);

            // now the hard work starts.
            Element el = doc.getDocumentElement();

            OpenContentElement oce = 
                    ObjectFactory.getInstance().unmarshallOpenContentElement(el);

            assertTrue(oce instanceof DSMLAttr);

            System.out.println("parsed xml to \n" + oce.toXML());
        }
        catch (Exception e) {
            fail(e.getMessage());
        }

    }

}
